@@ -12,7 +12,13 @@ pc_nature <- function(no_causality, positive, negative, dark) {
   )
 }
 
+#' Print Method for Pattern Causality Nature Analysis
+#'
+#' @param x A pc_nature object
+#' @param ... Additional arguments passed to print
+#' @return Invisibly returns the input object
 #' @export
+#' @method print pc_nature
 print.pc_nature <- function(x, ...) {
   cat("Pattern Causality Nature Analysis\n")
   cat("--------------------------------\n")
@@ -20,4 +26,5 @@ print.pc_nature <- function(x, ...) {
   cat("Positive Causality:", sum(x$positive > 0, na.rm = TRUE), "\n")
   cat("Negative Causality:", sum(x$negative > 0, na.rm = TRUE), "\n")
   cat("Dark Causality:", sum(x$dark > 0, na.rm = TRUE), "\n")
-} 
\ No newline at end of file
+  invisible(x)
+}
\ No newline at end of file
